@@ -450,6 +450,9 @@ pub fn evaluate_schedule_adjust_numerical_scale(
                     Circuit::ScalarConstant(_) | Circuit::ArrayConstant(_) | Circuit::Symbol(_) => {
                         panic!("constant found as schedule instruction, not supposed to happen")
                     }
+                    _ => {
+                        unimplemented!()
+                    }
                 };
                 assert!(result.0.shape()[..] == circ.info().shape[..]);
                 live.insert(circ.info().hash, result);
