@@ -133,6 +133,10 @@ fn rust_circuit(py: Python<'_>, m: &PyModule) -> PyResult<()> {
     m.add_class::<circuit::scheduled_execution::Schedule>()?;
     m.add_class::<circuit::scheduled_execution::ScheduleStats>()?;
 
+    m.add_class::<circuit::module_nodes::ModuleNode>()?;
+    m.add_class::<circuit::module_nodes::ModuleNodeSpec>()?;
+    m.add_class::<circuit::module_nodes::ModuleNodeArgSpec>()?;
+
     m.add_function(wrap_pyfunction!(add_collapse_scalar_inputs, m)?)?;
     m.add_function(wrap_pyfunction!(add_deduplicate, m)?)?;
     m.add_function(wrap_pyfunction!(remove_add_few_input, m)?)?;
@@ -264,9 +268,23 @@ fn rust_circuit(py: Python<'_>, m: &PyModule) -> PyResult<()> {
     m.add_function(wrap_pyfunction!(update_nodes_py, m)?)?;
     m.add_function(wrap_pyfunction!(path_get, m)?)?;
     m.add_function(wrap_pyfunction!(update_path_py, m)?)?;
+    m.add_function(wrap_pyfunction!(circuit::module_nodes::expand_node_py, m)?)?;
     m.add_function(wrap_pyfunction!(rrfs::save_tensor_rrfs, m)?)?;
     m.add_function(wrap_pyfunction!(rrfs::tensor_from_hash, m)?)?;
+    m.add_function(wrap_pyfunction!(
+        circuit::module_nodes::inline_all_modules,
+        m
+    )?)?;
+    m.add_function(wrap_pyfunction!(
+        circuit::module_nodes::replace_expand_bottom_up_dict_py,
+        m
+    )?)?;
+    m.add_function(wrap_pyfunction!(
+        circuit::module_nodes::replace_expand_bottom_up_py,
+        m
+    )?)?;
 
     // add more py function as desired or whatever...
+
     Ok(())
 }
