@@ -342,6 +342,35 @@ impl EinsumSpec {
         }
     }
 
+    #[staticmethod]
+    pub fn fancy_string_to_ints(string: String) -> (Vec<EinsumAxes>, EinsumAxes) {
+        if let [inputs, output] = string.split("->").collect::<Vec<&str>>()[..] {
+            let mut string_to_int: HashMap<&str, u8> = HashMap::new();
+            let input_ints = inputs
+                .split(',')
+                .map(|string| {
+                    string
+                        .split_whitespace()
+                        .map(|x| {
+                            let l = string_to_int.len() as u8;
+                            string_to_int.entry(x).or_insert(l).clone()
+                        })
+                        .collect()
+                })
+                .collect();
+            let output_ints = output
+                .split_whitespace()
+                .map(|x| {
+                    let l = string_to_int.len() as u8;
+                    string_to_int.entry(x).or_insert(l).clone()
+                })
+                .collect();
+            (input_ints, output_ints)
+        } else {
+            panic!()
+        }
+    }
+
     pub fn optimize_pre_contract_subsets(
         &self,
         dont_contract_subsets_into: Option<Vec<usize>>,
