@@ -81,7 +81,7 @@ pub fn broadcast_shapes(shapes: &Vec<Shape>) -> Result<Shape, TensorInvariantErr
 }
 
 // we could bit pack if we wanted...
-#[derive(Debug, Clone, Copy)]
+#[derive(Debug, Clone, Copy, PartialEq, Eq, Hash)]
 pub struct Slice {
     pub start: Option<i64>,
     pub stop: Option<i64>,
@@ -264,7 +264,7 @@ impl From<USlice> for TensorAxisIndex {
 }
 
 /// for now, doesn't support tensors with negatives
-#[derive(Debug, Clone, FromPyObject)]
+#[derive(Debug, Clone, FromPyObject, PartialEq, Eq)]
 pub enum TensorAxisIndex {
     Tensor(Tensor), // tensor needs to come first so len 1 tensors go to tensor not single
     Single(i64),
